from distutils.core import setup
setup(
  name = 'email_phone_block',
  packages = ['email_phone_block'],
  version = '0.5',
  description = 'Substitute emails and phone numbers with dummy in your text.',
  long_description=open('README.md').read(),
  author = 'Mauro De Giorgi',
  author_email = 'mauro.degiorgi@gmail.com',
  url = 'https://github.com/mdgart/email_phone_block',
  download_url = 'https://github.com/mdgart/email_phone_block/tarball/0.5',
  keywords = ['email', 'phone number', 'filter', 'blocking', 'text'],
  classifiers = [],
)